import * as Y from 'yjs';
import { Awareness } from 'y-protocols/awareness';
import * as mutex from 'lib0/mutex';
import { CloseEvent, MessageEvent, OpenEvent } from 'ws';
import EventEmitter from './EventEmitter';
import { OutgoingMessage } from './OutgoingMessage';
export declare enum WebSocketStatus {
    Connecting = "connecting",
    Connected = "connected",
    Disconnected = "disconnected"
}
export interface HocuspocusProviderOptions {
    url: string;
    name: string;
    document: Y.Doc;
    connect: boolean;
    broadcast: boolean;
    awareness: Awareness;
    token: string;
    parameters: {
        [key: string]: any;
    };
    WebSocketPolyfill: any;
    forceSyncInterval: false | number;
    reconnectTimeoutBase: number;
    maxReconnectTimeout: number;
    messageReconnectTimeout: number;
    onAuthenticated: () => void;
    onAuthenticationFailed: ({ reason: string }: {
        reason: any;
    }) => void;
    onOpen: (event: OpenEvent) => void;
    onConnect: () => void;
    onMessage: (event: MessageEvent) => void;
    onOutgoingMessage: (message: OutgoingMessage) => void;
    onStatus: (status: any) => void;
    onSynced: () => void;
    onDisconnect: (event: CloseEvent) => void;
    onClose: (event: CloseEvent) => void;
    onDestroy: () => void;
    onAwarenessUpdate: (states: any) => void;
    onAwarenessChange: (states: any) => void;
    debug: boolean;
}
export declare class HocuspocusProvider extends EventEmitter {
    options: HocuspocusProviderOptions;
    awareness: Awareness;
    subscribedToBroadcastChannel: boolean;
    webSocket: any;
    shouldConnect: boolean;
    status: WebSocketStatus;
    failedConnectionAttempts: number;
    isSynced: boolean;
    isAuthenticated: boolean;
    lastMessageReceived: number;
    mux: mutex.mutex;
    intervals: any;
    constructor(options?: Partial<HocuspocusProviderOptions>);
    setOptions(options?: Partial<HocuspocusProviderOptions>): void;
    get document(): Y.Doc;
    get awareness(): Awareness;
    checkConnection(): void;
    forceSync(): void;
    registerBeforeUnloadEventListener(): void;
    documentUpdateHandler(update: Uint8Array, origin: any): void;
    awarenessUpdateHandler({ added, updated, removed }: any, origin: any): void;
    permissionDeniedHandler(reason: string): void;
    authenticatedHandler(): void;
    get serverUrl(): string;
    get url(): string;
    get synced(): boolean;
    set synced(state: boolean);
    get isAuthenticationRequired(): boolean;
    connect(): void;
    disconnect(): void;
    createWebSocketConnection(): void;
    onOpen(event: OpenEvent): void;
    webSocketConnectionEstablished(): void;
    startSync(): void;
    send(Message: OutgoingMessage, args: any, broadcast?: boolean): void;
    onMessage(event: MessageEvent): void;
    onClose(event: CloseEvent): void;
    destroy(): void;
    get broadcastChannel(): string;
    broadcastChannelSubscriber(data: ArrayBuffer): void;
    subscribeToBroadcastChannel(): void;
    disconnectBroadcastChannel(): void;
    broadcast(Message: OutgoingMessage, args: any): void;
    log(message: string): void;
    setAwarenessField(key: string, value: any): void;
}
